@@ -117,8 +117,8 @@ Plot.FA <- function(FA, titles = NA, xlabel = NA, ylabel = NA, size = 1.1,
   #####   FIM - Informacoes usadas nos Graficos  #####
   
   if (savptc) {
-     cat("\014") # limpa a tela
-     cat("\n\n Saving graphics to hard disk. Wait for the end!")
+     message("\014") # limpa a tela
+     message("\n\n Saving graphics to hard disk. Wait for the end!")
   }
   
   if (casc && !savptc) dev.new() # efeito cascata na apresentacao dos graficos
@@ -400,6 +400,6 @@ Plot.FA <- function(FA, titles = NA, xlabel = NA, ylabel = NA, size = 1.1,
   if (savptc) { box(col = 'white'); dev.off() }
   ##### FIM - Biplot #####
   
-  if (savptc) cat("\n \n Fim!")
+  if (savptc) message("\n \n Fim!")
   
 }
\ No newline at end of file
